SystemOrganization addCategory: #ConfigurationOfParasol!

Object subclass: #ConfigurationOfParasol
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfParasol'!

!ConfigurationOfParasol class methodsFor: 'development support' stamp: 'KrisGybels 6/22/2012 17:19'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfParasol class methodsFor: 'private' stamp: 'KrisGybels 6/22/2012 17:19'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfParasol class methodsFor: 'private' stamp: 'KrisGybels 6/22/2012 17:19'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfParasol class methodsFor: 'private' stamp: 'KrisGybels 6/22/2012 17:19'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfParasol class methodsFor: 'metacello tool support' stamp: 'KrisGybels 6/22/2012 17:19'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfParasol class methodsFor: 'loading' stamp: 'KrisGybels 7/4/2012 16:44'!
load

	"self load"

	<apiDocumentation>
	^(self project version: '1.0-baseline') load! !

!ConfigurationOfParasol class methodsFor: 'accessing' stamp: 'KrisGybels 6/22/2012 17:19'!
project

	^self new project! !

!ConfigurationOfParasol class methodsFor: 'development support' stamp: 'KrisGybels 6/22/2012 17:19'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfParasol methodsFor: 'baselines' stamp: 'JohanBrichau 9/16/2013 17:59'!
baseline10: spec

	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec
			blessing: #baseline;
			repository: 'http://ss3.gemstone.com/ss/Parasol';
			yourself.
		spec 
			project: 'Seaside30' with: [
				spec
					className: 'ConfigurationOfSeaside3';
					version: #stable;
					file: 'ConfigurationOfSeaside3';
					repository: 'http://www.smalltalkhub.com/mc/Seaside/MetacelloConfigurations/main/'];
			yourself.
		spec
			package: 'Parasol-Core';
			package: 'Parasol-Tests' with: [ spec requires: #('Parasol-Core' 'Seaside30') ];
			package: 'Parasol-Convenience' with: [ spec requires: #('Parasol-Core') ];
			yourself.
		spec
			group: 'default' with: #('Parasol-Core' 'Parasol-Convenience');
			group: 'dev' with: #('Parasol-Tests' 'default');
			yourself.
	].

	spec for: #squeak do: [
		spec
			project: 'Seaside30' with: [	spec loads: #('Core' 'WebClient-Seaside')];
			yourself.
		spec 
			project: 'WebClient' with: [
				spec
					className: 'ConfigurationOfWebClient';
					version: #stable;
					file: 'ConfigurationOfWebClient';
					repository: 'http://www.squeaksource.com/MetacelloRepository'];
			yourself.
		spec
			package: 'Parasol-Squeak' with: [ spec requires: #('Parasol-Core' 'Seaside30' 'WebClient') ];
			yourself.
		spec
			group: 'default' 	with: #('Parasol-Squeak');
			yourself.
	].

	spec for: #pharo do: [
		"Sets the Zinc prerequisite for Pharo"
			spec 
				project: 'ZincHTTP'
				with: 
					[ spec
						className: 'ConfigurationOfZincHTTPComponents';
						versionString: #stable;
						file: 'ConfigurationOfZincHTTPComponents';
						loads: 'Core';
						repository: 'http://mc.stfx.eu/ZincHTTPComponents'].
		spec 
			package: 'Parasol-Core' 
			with: [ spec requires: #('ZincHTTP') ].
	].

	spec for: #'pharo1.x'  do: [
		spec 
			project: 'Seaside30' with: [
				spec
					className: 'ConfigurationOfSeaside3';
					versionString: '3.0.7.1';
					file: 'ConfigurationOfSeaside3';
					loads: #('Core' 'Seaside-Adaptors-Comanche');
					repository: 'http://www.smalltalkhub.com/mc/Seaside/MetacelloConfigurations/main/'];
			yourself.
		spec 
			package: 'Parasol-Pharo' with: [ spec requires: #('Parasol-Core')];
			yourself.
		spec
			group: 'default' 	with: #('Parasol-Pharo');
			yourself.
	].

	spec for: #'pharo2.x' do: [
		spec
			project: 'Seaside30' overrides: [
				spec
					className: 'ConfigurationOfSeaside3';
					versionString: '3.0.8';
					file: 'ConfigurationOfSeaside3';
					loads: #('Core' 'Zinc-Seaside');
					repository: 'http://www.smalltalkhub.com/mc/Seaside/MetacelloConfigurations/main/'];
			yourself.
			
			spec 
			package: 'Parasol-Pharo' with: [ spec requires: #('Parasol-Core')];
			yourself.
		spec
			group: 'default' 	with: #('Parasol-Pharo');
			yourself.
	].
	
	spec for: #gemstone do: [
		spec baseline: 'ZincHTTP'.
		spec 
			project: 'Seaside30' with: [ spec loads: #('Core') ];
			yourself.
		spec
			package: 'Parasol-Core' with: [ spec requires: #('ZincHTTP') ];
			yourself.
	].
	
	spec for: #'gs2.4.x' do: [
		spec 
			baseline: 'ZincHTTP' with: [
				spec
					className: 'BaselineOfZinc';
					loads: 'Core';
					repository: 'github://glassdb/zinc:gemstone2.4/repository'];
			yourself.
	].
		
	spec for: #'gs3.1.x' do:[
		spec 
			baseline: 'ZincHTTP' with: [
				spec
					className: 'BaselineOfZinc';
					loads: 'Core';
					repository: 'github://glassdb/zinc:gemstone3.1/repository'];
			yourself.
	].
! !

!ConfigurationOfParasol methodsFor: 'baselines' stamp: 'JohanBrichau 1/9/2014 09:17'!
baseline11: spec

	<version: '1.1-baseline'>
	
	spec for: #common do: [
		spec
			blessing: #baseline;
			repository: 'http://ss3.gemstone.com/ss/Parasol'.
			
		spec 
			project: 'Seaside3' 
			with: [
				spec
					className: 'ConfigurationOfSeaside3';
					version: #stable;
					loads: #('Tests' 'Zinc-Seaside');
					repository: 'http://www.smalltalkhub.com/mc/Seaside/MetacelloConfigurations/main/'].
				
		spec
			package: 'Parasol-Core';
			package: 'Parasol-Tests' with: [ spec requires: #('Parasol-Core' 'Seaside3') ];
			package: 'Parasol-Convenience' with: [ spec requires: #('Parasol-Core') ].
			
		spec
			group: 'default' with: #('Parasol-Core' 'Parasol-Convenience');
			group: 'dev' with: #('Parasol-Tests' 'default').
	].

	spec for: #squeak do: [
		spec
			project: 'Seaside3' 
			with: [ spec loads: #('Tests' 'WebClient-Seaside')].
				
		spec 
			project: 'WebClient' with: [
				spec
					className: 'ConfigurationOfWebClient';
					version: #stable;
					repository: 'http://www.squeaksource.com/MetacelloRepository'].
		spec
			package: 'Parasol-Squeak' with: [ spec requires: #('Parasol-Core' 'Seaside30' 'WebClient') ].
		spec
			 group: 'default' 	with: #('Parasol-Squeak').
	].

	spec for: #pharo do: [
		"Sets the Zinc prerequisite for Pharo"
			spec 
				project: 'ZincHTTP'
				with: 
					[ spec
						className: 'ConfigurationOfZincHTTPComponents';
						versionString: #stable;
						loads: 'Core';
						repository: 'http://mc.stfx.eu/ZincHTTPComponents'].
		spec 
			package: 'Parasol-Core' 
			with: [ spec requires: #('ZincHTTP') ].
	].

	spec for: #'pharo1.x'  do: [
				
		spec 
			package: 'Parasol-Pharo' with: [ spec requires: #('Parasol-Core')].
			
		spec
			group: 'default' 	with: #('Parasol-Pharo').
	].

	spec for: #('pharo2.x' 'pharo3.x') do: [
			
		spec 
			package: 'Parasol-Pharo' with: [ spec requires: #('Parasol-Core')].
			
		spec
			group: 'default' 	with: #('Parasol-Pharo').
				
	].
	
	spec for: #gemstone do: [
		spec baseline: 'ZincHTTP'.
			
		spec
			package: 'Parasol-Core' with: [ spec requires: #('ZincHTTP') ].
	].
	
	spec for: #'gs2.4.x' do: [
		spec 
			baseline: 'ZincHTTP' with: [
				spec
					className: 'BaselineOfZinc';
					loads: 'Core';
					repository: 'github://glassdb/zinc:gemstone2.4/repository'].
	].
		
	spec for: #'gs3.1.x' do:[
		spec 
			baseline: 'ZincHTTP' with: [
				spec
					className: 'BaselineOfZinc';
					loads: 'Core';
					repository: 'github://glassdb/zinc:gemstone3.1/repository'].
	].
! !

!ConfigurationOfParasol methodsFor: 'baselines' stamp: 'chaerle 8/20/2014 11:51'!
baseline12: spec

	<version: '1.2-baseline'>
	
	spec for: #common do: [
		spec
			blessing: #baseline;
			repository: 'http://ss3.gemstone.com/ss/Parasol'.
			
		spec 
			project: 'Seaside3' 
			with: [
				spec
					className: 'ConfigurationOfSeaside3';
					version: #stable;
					loads: #('Tests' 'Zinc-Seaside');
					repository: 'http://www.smalltalkhub.com/mc/Seaside/MetacelloConfigurations/main/'].
				
		spec
			package: 'Parasol-Core';
			package: 'Parasol-Tests' with: [ spec requires: #('Parasol-Core' 'Seaside3') ];
			package: 'Parasol-Convenience' with: [ spec requires: #('Parasol-Core') ].
			
		spec
			group: 'default' with: #('Parasol-Core' 'Parasol-Convenience');
			group: 'dev' with: #('Parasol-Tests' 'default').
	].

	spec for: #squeak do: [
		spec
			project: 'Seaside3' 
			with: [ spec loads: #('Tests' 'WebClient-Seaside')].
				
		spec 
			project: 'WebClient' with: [
				spec
					className: 'ConfigurationOfWebClient';
					version: #stable;
					repository: 'http://www.squeaksource.com/MetacelloRepository'].
		spec
			package: 'Parasol-Squeak' with: [ spec requires: #('Parasol-Core' 'Seaside3' 'WebClient') ];
			package: 'Parasol-Core' with: [ spec includes: #('Parasol-Squeak') ].
	].

	spec for: #pharo do: [
		"Sets the Zinc prerequisite for Pharo"
			spec 
				project: 'ZincHTTP'
				with: 
					[ spec
						className: 'ConfigurationOfZincHTTPComponents';
						versionString: #stable;
						loads: 'Core';
						repository: 'http://mc.stfx.eu/ZincHTTPComponents'].
		spec 
			package: 'Parasol-Pharo' with: [ spec requires: #('Parasol-Core')];
			package: 'Parasol-Core' with: [ spec requires: #('ZincHTTP'); includes:#('Parasol-Pharo') ].
	].
	
	spec for: #gemstone do: [
		spec baseline: 'ZincHTTP'.
			
		spec
			package: 'Parasol-Core' with: [ spec includes:#('Parasol-GemStone'); requires: #('ZincHTTP') ].
	].
	
	spec for: #'gs2.4.x' do: [
		spec 
			baseline: 'ZincHTTP' with: [
				spec
					className: 'BaselineOfZinc';
					loads: 'Core';
					repository: 'github://glassdb/zinc:gemstone2.4/repository'].
	].
		
	spec for: #'gs3.1.x' do:[
		spec 
			baseline: 'ZincHTTP' with: [
				spec
					className: 'BaselineOfZinc';
					loads: 'Core';
					repository: 'github://glassdb/zinc:gemstone3.1/repository'].
	].
! !

!ConfigurationOfParasol methodsFor: 'baselines' stamp: 'JohanBrichau 10/18/2014 15:51'!
baseline13: spec

	<version: '1.3-baseline'>
	
	spec for: #common do: [
		spec
			blessing: #baseline;
			repository: 'http://ss3.gemtalksystems.com/ss/Parasol'.
			
		spec 
			project: 'Seaside3' 
			with: [
				spec
					className: 'ConfigurationOfSeaside3';
					version: #stable;
					loads: #('Tests' 'Zinc-Seaside');
					repository: 'http://www.smalltalkhub.com/mc/Seaside/MetacelloConfigurations/main/'].
				
		spec
			package: 'Parasol-Core';
			package: 'Parasol-Tests' with: [ spec requires: #('Parasol-Core' 'Seaside3') ];
			package: 'Parasol-Convenience' with: [ spec requires: #('Parasol-Core') ].
			
		spec
			group: 'default' with: #('Parasol-Core' 'Parasol-Convenience');
			group: 'dev' with: #('Parasol-Tests' 'default').
	].

	spec for: #squeak do: [
		spec
			project: 'Seaside3' 
			with: [ spec loads: #('Tests' 'WebClient-Seaside')].
				
		spec 
			project: 'WebClient' with: [
				spec
					className: 'ConfigurationOfWebClient';
					version: #stable;
					repository: 'http://www.squeaksource.com/MetacelloRepository'].
		spec
			package: 'Parasol-Squeak' with: [ spec requires: #('Parasol-Core' 'Seaside3' 'WebClient') ];
			package: 'Parasol-Core' with: [ spec includes: #('Parasol-Squeak') ].
	].

	spec for: #pharo do: [
		"Sets the Zinc prerequisite for Pharo"
			spec 
				project: 'ZincHTTP'
				with: 
					[ spec
						className: 'ConfigurationOfZincHTTPComponents';
						versionString: #stable;
						loads: 'Core';
						repository: 'http://mc.stfx.eu/ZincHTTPComponents'].
		spec 
			package: 'Parasol-Pharo' with: [ spec requires: #('Parasol-Core')];
			package: 'Parasol-Core' with: [ spec requires: #('ZincHTTP'); includes:#('Parasol-Pharo') ].
	].
	
	spec for: #gemstone do: [
		spec baseline: 'ZincHTTP'.
			
		spec
			package: 'Parasol-Core' with: [ spec includes:#('Parasol-GemStone'); requires: #('ZincHTTP') ].
	].
	
	spec for: #'gs2.4.x' do: [
		spec 
			baseline: 'ZincHTTP' with: [
				spec
					className: 'BaselineOfZinc';
					loads: 'Core';
					repository: 'github://GsDevKit/zinc:2.3.2_gs2.4/repository'].
	].
		
	spec for: #'gs3.x' do:[
		spec 
			baseline: 'ZincHTTP' with: [
				spec
					className: 'BaselineOfZincHTTPComponents';
					loads: 'Core';
					repository: 'github://GsDevKit/zinc:2.4.3/repository'].
	].
! !

!ConfigurationOfParasol methodsFor: 'symbolic versions' stamp: 'JohanBrichau 10/18/2014 13:39'!
bleedingEdge: spec

	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '1.3-baseline'.
! !

!ConfigurationOfParasol methodsFor: 'symbolic versions' stamp: 'KrisGybels 1/25/2017 15:28'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.30'.
! !

!ConfigurationOfParasol methodsFor: 'accessing' stamp: 'KrisGybels 6/22/2012 17:19'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfParasol methodsFor: 'symbolic versions' stamp: 'JohanBrichau 4/14/2013 16:28'!
stable: spec

	<symbolicVersion: #'stable'>

	spec for: #'common' version: #notDefined.
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'JohanBrichau 11/7/2013 17:31'!
version010: spec
	<version: '0.10' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'JohanBrichau'.
		spec timestamp: '5/31/2013 20:50'.
		spec project: 'Seaside30' with: '3.0.8'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-JohanBrichau.23';
			package: 'Parasol-Tests' with: 'Parasol-Tests-AndyKellens.9';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-ThomasCleenewerck.5'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside30' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'. ].

	spec for: #'pharo1.x' do: [
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.3'. ].

	spec for: #'pharo2.x' do: [
		spec project: 'Seaside30' with: '3.0.8'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside30' with: '3.0.8'.
		spec package: 'Parasol-Core'. ].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'JohanBrichau 11/7/2013 17:31'!
version011: spec
	<version: '0.11' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec project: 'Seaside30' with: '3.0.8'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.26';
			package: 'Parasol-Tests' with: 'Parasol-Tests-AndyKellens.9';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-ThomasCleenewerck.5'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside30' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'. ].

	spec for: #'pharo1.x' do: [
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.3'. ].

	spec for: #'pharo2.x' do: [
		spec project: 'Seaside30' with: '3.0.8'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside30' with: '3.0.8'.
		spec package: 'Parasol-Core'. ].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'JohanBrichau 11/7/2013 17:30'!
version012: spec
	<version: '0.12' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec project: 'Seaside30' with: '3.0.8'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.26';
			package: 'Parasol-Tests' with: 'Parasol-Tests-JohanBrichau.10';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-ThomasCleenewerck.5'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside30' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'. ].

	spec for: #'pharo1.x' do: [
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.3'. ].

	spec for: #'pharo2.x' do: [
		spec project: 'Seaside30' with: '3.0.8'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside30' with: '3.0.8'.
		spec package: 'Parasol-Core'. ].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'JohanBrichau 11/7/2013 17:38'!
version013: spec
	<version: '0.13' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec project: 'Seaside30' with: '3.0.8'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.29';
			package: 'Parasol-Tests' with: 'Parasol-Tests-KrisGybels.11';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-ThomasCleenewerck.5'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside30' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'. ].

	spec for: #'pharo1.x' do: [
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.3'. ].

	spec for: #'pharo2.x' do: [
		spec project: 'Seaside30' with: '3.0.8'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside30' with: '3.0.8'.
		spec package: 'Parasol-Core'. ].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'JohanBrichau 11/7/2013 17:38'!
version014: spec
	<version: '0.14' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec project: 'Seaside30' with: '3.0.8'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.30';
			package: 'Parasol-Tests' with: 'Parasol-Tests-KrisGybels.11';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-ThomasCleenewerck.5'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside30' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'. ].

	spec for: #'pharo1.x' do: [
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.3'. ].

	spec for: #'pharo2.x' do: [
		spec project: 'Seaside30' with: '3.0.8'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside30' with: '3.0.8'.
		spec package: 'Parasol-Core'. ].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'JohanBrichau 1/5/2014 14:32'!
version015: spec
	<version: '0.15' imports: #('1.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec project: 'Seaside3' with: #stable.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.30';
			package: 'Parasol-Tests' with: 'Parasol-Tests-JohanBrichau.12';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-ThomasCleenewerck.5'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #stable;
			project: 'WebClient' with: #stable.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'. ].

	spec for: #'pharo1.x' do: [
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.3'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside30' with: '3.0.8'.
		spec package: 'Parasol-Core'. ].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'JohanBrichau 3/7/2014 08:48'!
version016: spec
	<version: '0.16' imports: #('1.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec project: 'Seaside3' with: #stable.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-JohanBrichau.32';
			package: 'Parasol-Tests' with: 'Parasol-Tests-JohanBrichau.12';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-JohanBrichau.6'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #stable;
			project: 'WebClient' with: #stable.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'. ].

	spec for: #'pharo1.x' do: [
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.3'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside30' with: '3.0.8'.
		spec package: 'Parasol-Core'. ].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'KrisGybels 7/9/2014 22:59'!
version017: spec
	<version: '0.17' imports: #('1.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec project: 'Seaside3' with: #stable.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.35';
			package: 'Parasol-Tests' with: 'Parasol-Tests-JohanBrichau.15';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-JohanBrichau.6'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #stable;
			project: 'WebClient' with: #stable.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'. ].

	spec for: #'pharo1.x' do: [
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.3'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside30' with: '3.0.8'.
		spec package: 'Parasol-Core'. ].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'chaerle 8/20/2014 11:50'!
version018: spec
	<version: '0.18' imports: #('1.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec project: 'Seaside3' with: #stable.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-JohanBrichau.38';
			package: 'Parasol-Tests' with: 'Parasol-Tests-JohanBrichau.17';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-JohanBrichau.8'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #stable;
			project: 'WebClient' with: #stable.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'.
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-JohanBrichau.4'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside3' with: #stable.
		spec package: 'Parasol-GemStone' with: 'Parasol-GemStone-JohanBrichau.5'].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'JohanBrichau 9/11/2014 10:14'!
version019: spec
	<version: '0.19' imports: #('1.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'JohanBrichau'.
		spec timestamp: '9/5/2014 14:46'.
		spec project: 'Seaside3' with: #'stable'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.50';
			package: 'Parasol-Tests' with: 'Parasol-Tests-KrisGybels.26';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-KrisGybels.11'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'.
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.9'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside3' with: #'stable'.
		spec package: 'Parasol-GemStone' with: 'Parasol-GemStone-JohanBrichau.10'. ].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'KrisGybels 9/12/2014 09:24'!
version020: spec
	<version: '0.20' imports: #('1.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'CarstenHaerle'.
		spec timestamp: '9/11/2014 17:05'.
		spec project: 'Seaside3' with: #'stable'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-CarstenHaerle.51';
			package: 'Parasol-Tests' with: 'Parasol-Tests-CarstenHaerle.27';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-CarstenHaerle.12'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'.
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.9'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside3' with: #'stable'.
		spec package: 'Parasol-GemStone' with: 'Parasol-GemStone-JohanBrichau.10'. ].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'JohanBrichau 10/4/2014 19:45'!
version021: spec
	<version: '0.21' imports: #('1.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'KrisGybels'.
		spec timestamp: '9/12/2014 09:19'.
		spec project: 'Seaside3' with: #'stable'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.52';
			package: 'Parasol-Tests' with: 'Parasol-Tests-KrisGybels.28';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-CarstenHaerle.12'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'.
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.9'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'Seaside3' with: #'stable'.
		spec package: 'Parasol-GemStone' with: 'Parasol-GemStone-JohanBrichau.10'. ].

! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'JohanBrichau 10/18/2014 13:39'!
version022: spec
	<version: '0.22' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'KrisGybels'.
		spec timestamp: '9/12/2014 09:19'.
		spec project: 'Seaside3' with: #'stable'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.52';
			package: 'Parasol-Tests' with: 'Parasol-Tests-KrisGybels.28';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-CarstenHaerle.12'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'.
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.9'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'Seaside3' with: #'stable'.
		spec package: 'Parasol-GemStone' with: 'Parasol-GemStone-JohanBrichau.10'. ].

! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'JohanBrichau 11/21/2014 17:28'!
version023: spec
	<version: '0.23' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'JohanBrichau'.
		spec timestamp: '11/21/2014 09:19'.
		spec project: 'Seaside3' with: #'stable'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.52';
			package: 'Parasol-Tests' with: 'Parasol-Tests-KrisGybels.28';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-CarstenHaerle.12'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'.
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.9'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'Seaside3' with: #'stable'.
		spec package: 'Parasol-GemStone' with: 'Parasol-GemStone-JohanBrichau.11'. ].

! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'JohanBrichau 5/4/2015 09:23'!
version024: spec
	<version: '0.24' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'JohanBrichau'.
		spec timestamp: '05/04/2015 09:23'.
		spec project: 'Seaside3' with: #'stable'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.52';
			package: 'Parasol-Tests' with: 'Parasol-Tests-KrisGybels.28';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-JohanBrichau.13'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'.
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.9'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'Seaside3' with: #'stable'.
		spec package: 'Parasol-GemStone' with: 'Parasol-GemStone-JohanBrichau.11'. ].

! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'KrisGybels 10/9/2015 15:27'!
version025: spec
	<version: '0.25' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'KrisGybels'.
		spec timestamp: '10/09/2015 14:50'.
		spec project: 'Seaside3' with: #'stable'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.60';
			package: 'Parasol-Tests' with: 'Parasol-Tests-KrisGybels.31';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-KrisGybels.15'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-KrisGybels.10'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'.
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.11'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'Seaside3' with: #'stable'.
		spec package: 'Parasol-GemStone' with: 'Parasol-GemStone-KrisGybels.12'. ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'JohanBrichau 3/11/2016 09:37'!
version026: spec
	<version: '0.26' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'JohanBrichau'.
		spec timestamp: '03/11/2016 09:38'.
		spec project: 'Seaside3' with: #'stable'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.60';
			package: 'Parasol-Tests' with: 'Parasol-Tests-KrisGybels.31';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-ThomasCleenewerck.16'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-KrisGybels.10'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'.
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.11'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'Seaside3' with: #'stable'.
		spec package: 'Parasol-GemStone' with: 'Parasol-GemStone-KrisGybels.12'. ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'AndyKellens 11/22/2016 14:44'!
version027: spec
	<version: '0.27' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'AndyKellens'.
		spec timestamp: '22/11/2016 14:40'.
		spec project: 'Seaside3' with: #'stable'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-AndyKellens.63';
			package: 'Parasol-Tests' with: 'Parasol-Tests-JohanBrichau.34';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-AndyKellens.17'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-KrisGybels.10'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'.
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-JohanBrichau.13'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'Seaside3' with: #'stable'.
		spec package: 'Parasol-GemStone' with: 'Parasol-GemStone-AndyKellens.13'. ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'KrisGybels 1/25/2017 13:29'!
version028: spec
	<version: '0.28' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec project: 'Seaside3' with: #'stable'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.67';
			package: 'Parasol-Tests' with: 'Parasol-Tests-KrisGybels.40';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-AndyKellens.17'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-smalltalkCI.11'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'.
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-JohanBrichau.13'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'Seaside3' with: #'stable'.
		spec package: 'Parasol-GemStone' with: 'Parasol-GemStone-AndyKellens.13'. ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'KrisGybels 1/25/2017 15:02'!
version029: spec
	<version: '0.29' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec project: 'Seaside3' with: #'stable'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.67';
			package: 'Parasol-Tests' with: 'Parasol-Tests-KrisGybels.41';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-AndyKellens.17'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-smalltalkCI.11'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'.
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-JohanBrichau.13'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'Seaside3' with: #'stable'.
		spec package: 'Parasol-GemStone' with: 'Parasol-GemStone-AndyKellens.13'. ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'KrisGybels 1/25/2017 15:27'!
version030: spec
	<version: '0.30' imports: #('1.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec project: 'Seaside3' with: #'stable'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-KrisGybels.68';
			package: 'Parasol-Tests' with: 'Parasol-Tests-KrisGybels.41';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-AndyKellens.17'. ].

	spec for: #'squeak' do: [
		spec 
			project: 'Seaside3' with: #'stable';
			project: 'WebClient' with: #'stable'.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-smalltalkCI.11'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'.
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-JohanBrichau.13'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'Seaside3' with: #'stable'.
		spec package: 'Parasol-GemStone' with: 'Parasol-GemStone-AndyKellens.13'. ].
! !

!ConfigurationOfParasol methodsFor: 'versions' stamp: 'topa 4/18/2013 08:21'!
version09: spec
	<version: '0.9' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec author: 'JohanBrichau'.
		spec timestamp: '4/14/2013 13:11'.
		spec project: 'Seaside30' with: '3.0.8'.
		spec 
			package: 'Parasol-Core' with: 'Parasol-Core-topa.22';
			package: 'Parasol-Tests' with: 'Parasol-Tests-AndyKellens.9';
			package: 'Parasol-Convenience' with: 'Parasol-Convenience-JohanBrichau.4'. ].

	spec for: #'squeak' do: [
		spec project: 'Seaside30' with: #stable.
		spec project: 'WebClient' with: #stable.
		spec package: 'Parasol-Squeak' with: 'Parasol-Squeak-topa.1'. ].

	spec for: #'pharo' do: [
		spec project: 'ZincHTTP' with: #'stable'. ].

	spec for: #'pharo1.x' do: [
		spec package: 'Parasol-Pharo' with: 'Parasol-Pharo-KrisGybels.3'. ].

	spec for: #'pharo2.x' do: [
		spec project: 'Seaside30' with: '3.0.8'. ].

	spec for: #'gemstone' do: [
		spec 
			baseline: 'ZincHTTP' ;
			project: 'Seaside30' .
		spec package: 'Parasol-Core'. ].

	spec for: #'gs2.4.x' do: [
		spec baseline: 'ZincHTTP' . ].

	spec for: #'gs3.1.x' do: [
		spec baseline: 'ZincHTTP' . ].
! !
